@@ -30,6 +30,7 @@ impl Default for ParserOptions {
         options.extension.front_matter_delimiter = Some("---".into());
         options.extension.table = true;
         options.extension.strikethrough = true;
+        options.extension.multiline_block_quotes = true;
         Self(options)
     }
 }
@@ -100,7 +101,7 @@ impl<'a> MarkdownParser<'a> {
             NodeValue::CodeBlock(block) => Self::parse_code_block(block, data.sourcepos)?,
             NodeValue::ThematicBreak => MarkdownElement::ThematicBreak,
             NodeValue::HtmlBlock(block) => Self::parse_html_block(block, data.sourcepos)?,
-            NodeValue::BlockQuote => Self::parse_block_quote(node)?,
+            NodeValue::BlockQuote | NodeValue::MultilineBlockQuote(_) => Self::parse_block_quote(node)?,
             other => return Err(ParseErrorKind::UnsupportedElement(other.identifier()).with_sourcepos(data.sourcepos)),
         };
         Ok(vec![element])
@@ -131,6 +132,9 @@ impl<'a> MarkdownParser<'a> {
     }
 
     fn parse_block_quote(node: &'a AstNode<'a>) -> ParseResult<MarkdownElement> {
+        // This renders the contents of this block quote AST as commonmark, given we otherwise
+        // would need to either do this outselves or pull the raw block contents off of the
+        // original raw string and that also isn't great.
         let mut buffer = BufWriter::new(Vec::new());
         let mut options = ParserOptions::default().0;
         options.render.list_style = ListStyleType::Star;
@@ -144,7 +148,14 @@ impl<'a> MarkdownParser<'a> {
                 Some(index) => line[index + 1..].trim(),
                 None => line,
             };
-            lines.push(line.to_string());
+            let mut line = line.to_string();
+            // `format_commonmark` escapes these symbols so we un-escape them.
+            for escape in &["\\*", "\\!", "\\[", "\\]", "\\#", "\\`", "\\<", "\\>"] {
+                if line.contains(escape) {
+                    line = line.replace(escape, &escape[1..]);
+                }
+            }
+            lines.push(line);
         }
         Ok(MarkdownElement::BlockQuote(lines))
     }
@@ -466,6 +477,7 @@ impl Identifier for NodeValue {
             NodeValue::Link(_) => "link",
             NodeValue::Image(_) => "image",
             NodeValue::FootnoteReference(_) => "footnote reference",
+            NodeValue::MultilineBlockQuote(_) => "multiline block quote",
         }
     }
 }
@@ -704,13 +716,34 @@ echo hi mom
     #[test]
     fn block_quote() {
         let parsed = parse_single(
-            r"
-> bar
+            r#"
+> bar!@#$%^&*()[]'"{}-=`~,.<>/?
 > foo
 > 
 > * a
 > * b
-",
+"#,
+        );
+        let MarkdownElement::BlockQuote(lines) = parsed else { panic!("not a block quote: {parsed:?}") };
+        assert_eq!(lines.len(), 5);
+        assert_eq!(lines[0], "bar!@#$%^&*()[]'\"{}-=`~,.<>/?");
+        assert_eq!(lines[1], "foo");
+        assert_eq!(lines[2], "");
+        assert_eq!(lines[3], "* a");
+        assert_eq!(lines[4], "* b");
+    }
+
+    #[test]
+    fn multiline_block_quote() {
+        let parsed = parse_single(
+            r"
+>>>
+bar
+foo
+
+* a
+* b
+>>>",
         );
         let MarkdownElement::BlockQuote(lines) = parsed else { panic!("not a block quote: {parsed:?}") };
         assert_eq!(lines.len(), 5);
