@@ -3,7 +3,7 @@ use crate::{
     markdown::text::WeightedTextBlock,
     media::image::Image,
     render::properties::WindowSize,
-    style::Colors,
+    style::{Color, Colors},
     theme::{Alignment, Margin, PresentationTheme},
 };
 use serde::Deserialize;
@@ -376,12 +376,12 @@ pub(crate) trait ChunkMutator: Debug {
     fn mutate_previous(&self) -> bool;
     fn reset_mutations(&self);
     fn apply_all_mutations(&self);
+    #[allow(dead_code)]
     fn mutations(&self) -> (usize, usize);
 }
 
 /// The metadata for a presentation.
 #[derive(Clone, Debug, Deserialize)]
-#[serde(deny_unknown_fields)]
 pub(crate) struct PresentationMetadata {
     /// The presentation title.
     pub(crate) title: Option<String>,
@@ -500,11 +500,12 @@ pub(crate) enum RenderOperation {
 }
 
 /// The properties of an image being rendered.
-#[derive(Clone, Debug, Default)]
+#[derive(Clone, Debug)]
 pub(crate) struct ImageProperties {
     pub(crate) z_index: i32,
     pub(crate) size: ImageSize,
     pub(crate) restore_cursor: bool,
+    pub(crate) background_color: Option<Color>,
 }
 
 /// The size used when printing an image.
