@@ -1,15 +1,13 @@
-use super::{engine::RenderEngine, media::GraphicsMode, terminal::Terminal};
+use super::{engine::RenderEngine, terminal::Terminal};
 use crate::{
-    markdown::{
-        elements::StyledText,
-        text::{WeightedLine, WeightedText},
-    },
+    markdown::{elements::Text, text::WeightedTextBlock},
+    media::printer::{ImagePrinter, PrintImageError},
     presentation::{Presentation, RenderOperation},
     render::properties::WindowSize,
     style::{Color, Colors, TextStyle},
     theme::{Alignment, Margin},
 };
-use std::io;
+use std::{io, rc::Rc};
 
 /// The result of a render operation.
 pub(crate) type RenderResult = Result<(), RenderError>;
@@ -17,7 +15,7 @@ pub(crate) type RenderResult = Result<(), RenderError>;
 /// Allows drawing elements in the terminal.
 pub(crate) struct TerminalDrawer<W: io::Write> {
     terminal: Terminal<W>,
-    graphics_mode: GraphicsMode,
+    font_size_fallback: u8,
 }
 
 impl<W> TerminalDrawer<W>
@@ -25,28 +23,24 @@ where
     W: io::Write,
 {
     /// Construct a drawer over a [std::io::Write].
-    pub(crate) fn new(handle: W, graphics_mode: GraphicsMode) -> io::Result<Self> {
-        let terminal = Terminal::new(handle)?;
-        Ok(Self { terminal, graphics_mode })
+    pub(crate) fn new(handle: W, image_printer: Rc<ImagePrinter>, font_size_fallback: u8) -> io::Result<Self> {
+        let terminal = Terminal::new(handle, image_printer)?;
+        Ok(Self { terminal, font_size_fallback })
     }
 
     /// Render a slide.
     pub(crate) fn render_slide(&mut self, presentation: &Presentation) -> RenderResult {
-        let window_dimensions = WindowSize::current()?;
+        let dimensions = WindowSize::current(self.font_size_fallback)?;
         let slide = presentation.current_slide();
-        let engine = RenderEngine::new(&mut self.terminal, window_dimensions, self.graphics_mode.clone());
+        let engine = self.create_engine(dimensions);
         engine.render(slide.iter_operations())?;
-        self.terminal.flush()?;
         Ok(())
     }
 
     /// Render an error.
     pub(crate) fn render_error(&mut self, message: &str) -> RenderResult {
-        let dimensions = WindowSize::current()?;
-        let heading = vec![
-            WeightedText::from(StyledText::new("Error loading presentation", TextStyle::default().bold())),
-            WeightedText::from(StyledText::from(": ")),
-        ];
+        let dimensions = WindowSize::current(self.font_size_fallback)?;
+        let heading = vec![Text::new("Error loading presentation", TextStyle::default().bold()), Text::from(": ")];
 
         let alignment = Alignment::Center { minimum_size: 0, minimum_margin: Margin::Percent(8) };
         let mut operations = vec![
@@ -56,20 +50,37 @@ where
                 background: Some(Color::new(0, 0, 0)),
             }),
             RenderOperation::JumpToVerticalCenter,
-            RenderOperation::RenderText { line: WeightedLine::from(heading), alignment: alignment.clone() },
+            RenderOperation::RenderText { line: WeightedTextBlock::from(heading), alignment: alignment.clone() },
             RenderOperation::RenderLineBreak,
             RenderOperation::RenderLineBreak,
         ];
         for line in message.lines() {
-            let error = vec![WeightedText::from(StyledText::from(line))];
-            let op = RenderOperation::RenderText { line: WeightedLine::from(error), alignment: alignment.clone() };
+            let error = vec![Text::from(line)];
+            let op = RenderOperation::RenderText { line: WeightedTextBlock::from(error), alignment: alignment.clone() };
             operations.extend([op, RenderOperation::RenderLineBreak]);
         }
-        let engine = RenderEngine::new(&mut self.terminal, dimensions, self.graphics_mode.clone());
+        let engine = self.create_engine(dimensions);
         engine.render(operations.iter())?;
-        self.terminal.flush()?;
         Ok(())
     }
+
+    pub(crate) fn render_slide_index(&mut self, presentation: &Presentation) -> RenderResult {
+        let dimensions = WindowSize::current(self.font_size_fallback)?;
+        let engine = self.create_engine(dimensions);
+        engine.render(presentation.iter_slide_index_operations())?;
+        Ok(())
+    }
+
+    pub(crate) fn render_key_bindings(&mut self, presentation: &Presentation) -> RenderResult {
+        let dimensions = WindowSize::current(self.font_size_fallback)?;
+        let engine = self.create_engine(dimensions);
+        engine.render(presentation.iter_bindings_operations())?;
+        Ok(())
+    }
+
+    fn create_engine(&mut self, dimensions: WindowSize) -> RenderEngine<W> {
+        RenderEngine::new(&mut self.terminal, dimensions)
+    }
 }
 
 /// A rendering error.
@@ -90,6 +101,9 @@ pub enum RenderError {
     #[error("tried to pop default screen")]
     PopDefaultScreen,
 
+    #[error("printing image: {0}")]
+    PrintImage(#[from] PrintImageError),
+
     #[error(transparent)]
     Other(Box<dyn std::error::Error>),
 }
