@@ -1,11 +1,17 @@
-use crate::style::Colors;
+use crate::{
+    media::{
+        image::Image,
+        printer::{ImagePrinter, PrintImage, PrintImageError, PrintOptions},
+    },
+    style::Colors,
+};
 use crossterm::{
     cursor,
     style::{self, StyledContent},
     terminal::{self},
     QueueableCommand,
 };
-use std::io;
+use std::{io, rc::Rc};
 
 /// A wrapper over the terminal write handle.
 pub(crate) struct Terminal<W>
@@ -13,16 +19,29 @@ where
     W: io::Write,
 {
     writer: W,
+    image_printer: Rc<ImagePrinter>,
     pub(crate) cursor_row: u16,
 }
 
 impl<W: io::Write> Terminal<W> {
-    pub(crate) fn new(mut writer: W) -> io::Result<Self> {
+    pub(crate) fn new(mut writer: W, image_printer: Rc<ImagePrinter>) -> io::Result<Self> {
         terminal::enable_raw_mode()?;
-        writer.queue(cursor::Hide)?;
+        if should_hide_cursor() {
+            writer.queue(cursor::Hide)?;
+        }
         writer.queue(terminal::EnterAlternateScreen)?;
 
-        Ok(Self { writer, cursor_row: 0 })
+        Ok(Self { writer, image_printer, cursor_row: 0 })
+    }
+
+    pub(crate) fn begin_update(&mut self) -> io::Result<()> {
+        self.writer.queue(terminal::BeginSynchronizedUpdate)?;
+        Ok(())
+    }
+
+    pub(crate) fn end_update(&mut self) -> io::Result<()> {
+        self.writer.queue(terminal::EndSynchronizedUpdate)?;
+        Ok(())
     }
 
     pub(crate) fn move_to(&mut self, column: u16, row: u16) -> io::Result<()> {
@@ -81,8 +100,17 @@ impl<W: io::Write> Terminal<W> {
         Ok(())
     }
 
-    pub(crate) fn sync_cursor_row(&mut self, position: u16) {
+    pub(crate) fn sync_cursor_row(&mut self, position: u16) -> io::Result<()> {
         self.cursor_row = position;
+        self.writer.queue(cursor::MoveToRow(position))?;
+        Ok(())
+    }
+
+    pub(crate) fn print_image(&mut self, image: &Image, options: &PrintOptions) -> Result<(), PrintImageError> {
+        self.move_to_column(options.cursor_position.column)?;
+        self.image_printer.print(&image.resource, options, &mut self.writer)?;
+        self.cursor_row += options.rows;
+        Ok(())
     }
 }
 
@@ -92,8 +120,24 @@ where
 {
     fn drop(&mut self) {
         let _ = self.writer.queue(terminal::LeaveAlternateScreen);
-        let _ = self.writer.queue(cursor::Show);
+        if should_hide_cursor() {
+            let _ = self.writer.queue(cursor::Show);
+        }
         let _ = self.writer.flush();
         let _ = terminal::disable_raw_mode();
     }
 }
+
+fn should_hide_cursor() -> bool {
+    // WezTerm on Windows fails to display images if we've hidden the cursor so we **always** hide it
+    // unless we're on WezTerm on Windows.
+    let term = std::env::var("TERM_PROGRAM");
+    let is_wezterm = term.as_ref().map(|s| s.as_str()) == Ok("WezTerm");
+    !(is_windows_based_os() && is_wezterm)
+}
+
+fn is_windows_based_os() -> bool {
+    let is_windows = std::env::consts::OS == "windows";
+    let is_wsl = std::env::var("WSL_DISTRO_NAME").is_ok();
+    is_windows || is_wsl
+}
